@@ -4,39 +4,29 @@ use strict;
 use vars qw($VERSION @ISA $errno);
 
 use Carp ;
-use Tk ;
-use Tk::Multi::Text ;
-use Data::Dumper ;
-use AutoLoader 'AUTOLOAD' ;
+use Tk::Derived ;
+use Tk::Frame;
 
-@ISA = qw(Tk::Frame);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
+@ISA = qw(Tk::Derived Tk::Frame);
 
-$VERSION = '0.01';
+$VERSION = '0.2';
 
 Tk::Widget->Construct('ObjScanner');
 
-# Preloaded methods go here.
-
-#stubs
-sub dumpKeyContent ;
-sub listScan ;
-sub updateListBox ;
-
-# Autoload methods go after =cut, and are processed by the autosplit program.
-
 sub Populate
   {
     my ($cw,$args) = @_ ;
     
+    require Tk::Menubutton ;
+    require Tk::Listbox ;
+    require Tk::Multi::Text ;
+
     my $title = 'scanner';
     $title = delete $args->{title} if defined $args->{title} ;
 
-    $cw->{dodu}{chief} = delete $args->{'caller'} ;
+    $cw->{chief} = delete $args->{'caller'} ;
     croak "Missing caller argument in ObjScanner\n" 
-      unless defined  $cw->{dodu}{chief};
+      unless defined  $cw->{chief};
 
     my $gf = $cw -> Frame (relief => 'raised', borderwidth => 3 ) -> pack ;
 
@@ -46,7 +36,7 @@ sub Populate
       Frame (-relief => 'raised', -borderwidth => 2)-> 
         pack(pady => 2,  fill => 'x' ) ;
 
-    my $menu = $cw->{dodu}{menu}= $menuframe -> Menubutton 
+    my $menu = $cw->{menu}= $menuframe -> Menubutton 
       (-text => $title.' menu') 
           -> pack ( fill => 'x' , side => 'left');
 
@@ -89,11 +79,11 @@ sub Populate
       ) ;
 
     # fill list box 
-    $cw->{dodu}{listbox}= $w_frame_list ;
+    $cw->{listbox}= $w_frame_list ;
     $cw->updateListBox;
 
     #pack MultiText
-    my $window = $cw->{dodu}{dumpWindow} = 
+    my $window = $cw->{dumpWindow} = 
       $gf -> MultiText ('menu_button' => $menu) -> pack(side => 'right') ;
 
     $window -> setSize(15,60);
@@ -106,11 +96,44 @@ sub Populate
     $cw->Delegates(DEFAULT => $window ) ;
   }
 
+sub dumpKeyContent
+  {
+    my $cw = shift ;
+    my $key =  shift ; # key to dump
+    
+    my %hash ;
+    $hash{$key} = $cw->{chief}{$key} ;
+    $cw->listScan(\%hash) ;
+  }
+
+sub listScan
+  {
+    my $cw = shift ;
+    my $ref =  shift ; # thing to dump, must be a hash ref
+
+    my $key ;
+    my $refs = [] ;
+    my $names = [] ;
+    foreach $key (keys %$ref)
+      {
+	push @$names, $key ;
+	push @$refs, $ref->{$key} ;
+      }
+    require Data::Dumper;
+    my $d = Data::Dumper->new ( $refs, $names ) ;
+    $cw->{dumpWindow}->insertText($d->Dumpxs) ;
+  }
+
+sub updateListBox
+  {
+    my $cw = shift ;
+    $cw->{listbox}->delete(0,'end') ;
+    $cw->{listbox}->insert('end', sort  keys %{$cw->{chief}} );
+  }
 
 1;
 
 __END__
-# Below is the stub of documentation for your module. You better edit it!
 
 =head1 NAME
 
@@ -120,7 +143,7 @@ Tk::ObjScanner - Tk composite widget object scanner
 
   use Tk::Multi::Text;
   
-  my $mgr = Tk::ObjScanner new ( caller => $object, [title=>"windows"]);
+  my $mgr = Tk::ObjScanner->new( caller => $object, [title=>"windows"]);
 
 =head1 DESCRIPTION
 
@@ -141,7 +164,7 @@ scan.
 The optionnal 'title' argument contains the title of the menu created by the 
 scanner.
 
-=head1 Methods
+=head1 WIDGET-SPECIFIC METHODS
 
 =head2 updateListBox
 
@@ -160,39 +183,3 @@ perl(1), Tk(3), Tk::Multi::Text(3), Data::Dumper(3)
 
 =cut
 
-# autoload methods
-
-sub dumpKeyContent
-  {
-    my $cw = shift ;
-    my $key =  shift ; # key to dump
-    
-    my %hash ;
-    $hash{$key} = $cw->{dodu}{chief}{$key} ;
-    $cw->listScan(\%hash) ;
-  }
-
-sub listScan
-  {
-    my $cw = shift ;
-    my $ref =  shift ; # thing to dump, must be a hash ref
-
-    my $key ;
-    my $refs = [] ;
-    my $names = [] ;
-    foreach $key (keys %$ref)
-      {
-	push @$names, $key ;
-	push @$refs, $ref->{$key} ;
-      }
-    my $d = Data::Dumper->new ( $refs, $names ) ;
-    $cw->{dodu}{dumpWindow}->insertText($d->Dumpxs) ;
-  }
-
-sub updateListBox
-  {
-    my $cw = shift ;
-    $cw->{dodu}{listbox}->delete(0,'end') ;
-    $cw->{dodu}{listbox}->insert('end', sort  keys %{$cw->{dodu}{chief}} );
-  }
-
